package com.ruoyi.project.demo.service.impl;

import com.ruoyi.project.demo.domain.RecordEntity;
import com.ruoyi.project.demo.mapper.RecordMapper;
import com.ruoyi.project.demo.service.service.RecordService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * FileName: RecordServiceImpl
 * DetailedDescription： 记录表逻辑层 （impl）
 *
 * @author cry
 * @version 1.00
 * @Date 2022-07-09
 */
@Service
public class RecordServiceImpl implements RecordService {

    /**
     * 记录表数据接口层
     */
    @Autowired
    private RecordMapper recordMapper;

    /**
     * 查询
     *
     * @param recordEntity 实体类
     * @return
     */
    @Override
    public List<RecordEntity> getRecord(RecordEntity recordEntity) {
        /**
         * 声明记录表集合，存储查询信息
         */
        List<RecordEntity> getRecord = null;
        //总条数
        Integer total = 0;
        try {
            /**
             * 查询相关信息
             */
            getRecord = recordMapper.getRecord(recordEntity);
            //查询总条数
            total = recordMapper.getRecordCount(recordEntity);
            //赋值总条数
            getRecord.get(0).setTotal(total);

        } catch (Exception e) {
            /**
             * 错误信息
             */
            e.printStackTrace();
        } finally {

            /**
             * 返回相关信息
             */
            return getRecord;
        }
    }

    /**
     * 添加
     *
     * @param recordEntity 实体类
     * @return 是否成功
     */
    @Override
    public Integer insertRecord(RecordEntity recordEntity) {
        /**
         * 状态信息
         */
        Integer flag = 0;

        try {
            /**
             * 请求Mapper层  添加信息
             */
            flag = recordMapper.insertRecord(recordEntity);
            /**
             * 返回操作状态
             */
            return flag;
        } catch (Exception e) {
            /**
             * 异常信息
             */
            e.printStackTrace();
            /**
             * 返回错误信息
             */
            return flag;
        }
    }

    /**
     * 修改
     *
     * @param recordEntity 实体类
     * @return 是否成功
     */
    @Override
    public Integer updateRecord(RecordEntity recordEntity) {
        /**
         * 状态信息
         */
        Integer flag = 0;

        try {
            /**
             * 验证唯一标识
             */
            if (recordEntity.getId() != null && recordEntity.getId() > 0) {
                /**
                 * 请求Mapper层  添加信息
                 */
                flag = recordMapper.updateRecord(recordEntity);
            }
            /**
             * 返回操作状态
             */
            return flag;
        } catch (Exception e) {
            /**
             * 异常信息
             */
            e.printStackTrace();
            /**
             * 返回错误信息
             */
            return flag;
        }
    }

    /**
     * 删除
     *
     * @param recordEntity 实体类
     * @return 是否成功
     */
    @Override
    public Integer removeRecord(RecordEntity recordEntity) {
        /**
         * 状态信息
         */
        Integer flag = 0;

        try {
            /**
             * 验证唯一标识
             */
            if (recordEntity.getId() != null && recordEntity.getId() > 0) {
                /**
                 * 逻辑删除
                 * */
                recordEntity.setDel(true);
                /**
                 * 请求Mapper层  添加信息
                 */
                flag = recordMapper.removeRecord(recordEntity);
            }
            /**
             * 返回操作状态
             */
            return flag;
        } catch (Exception e) {
            /**
             * 异常信息
             */
            e.printStackTrace();
            /**
             * 返回错误信息
             */
            return 0;
        }
    }
}
